=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2010-06-30 12:03:30 +0000
+++ bzrlib/errors.py	2010-07-09 16:16:11 +0000
@@ -3157,8 +3157,8 @@
 
 class InvalidPattern(BzrError):
 
-    _fmt = ('Invalid pattern(s) found. %(message)s')
+    _fmt = ('Invalid pattern(s) found. %(msg)s')
 
-    def __init__(self, message):
-        self.message = message
+    def __init__(self, msg):
+        self.msg = msg
 

=== modified file 'bzrlib/globbing.py'
--- bzrlib/globbing.py	2010-07-08 05:11:16 +0000
+++ bzrlib/globbing.py	2010-07-09 16:16:11 +0000
@@ -217,11 +217,11 @@
                 if match:
                     return patterns[match.lastindex -1]
         except errors.InvalidPattern, e:
-            # We can't show the default e.message to the user as thats for
+            # We can't show the default e.msg to the user as thats for
             # the combined pattern we sent to regex. Instead we indicate to
             # the user that an ignore file needs fixing.
-            mutter('Invalid pattern found in regex: %s.', e.message)
-            e.message = "File ~/.bazaar/ignore or .bzrignore contains errors."
+            mutter('Invalid pattern found in regex: %s.', e.msg)
+            e.msg = "File ~/.bazaar/ignore or .bzrignore contains errors."
             raise e
         return None
 

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2010-07-08 10:34:12 +0000
+++ bzrlib/osutils.py	2010-07-09 16:16:11 +0000
@@ -2184,7 +2184,7 @@
             where = ' in ' + where
         # despite the name 'error' is a type
         raise errors.BzrCommandError('Invalid regular expression%s: %s'
-            % (where, e.message))
+            % (where, e.msg))
 
 
 if sys.platform == "win32":

=== modified file 'bzrlib/tests/blackbox/test_log.py'
--- bzrlib/tests/blackbox/test_log.py	2010-06-30 12:03:30 +0000
+++ bzrlib/tests/blackbox/test_log.py	2010-07-09 16:16:11 +0000
@@ -387,6 +387,7 @@
         self.make_minimal_branch()
         out, err = self.run_bzr(['log', '-m', '*'], retcode=3)
         self.assertContainsRe(err, "ERROR.*Invalid pattern.*nothing to repeat")
+        self.assertNotContainsRe(err, "Unprintable exception")
         self.assertEqual(out, '')
 
     def test_log_unsupported_timezone(self):

=== modified file 'bzrlib/tests/test_errors.py'
--- bzrlib/tests/test_errors.py	2010-05-20 18:23:17 +0000
+++ bzrlib/tests/test_errors.py	2010-07-09 16:16:11 +0000
@@ -655,6 +655,11 @@
         str(err)
         self.assertEqual(['open_repository'], fake_bzrdir.calls)
 
+    def test_invalid_pattern(self):
+        error = errors.InvalidPattern('Bad pattern msg.')
+        self.assertEqualDiff("Invalid pattern(s) found. Bad pattern msg.",
+            str(error))
+
 
 class PassThroughError(errors.BzrError):
 

=== modified file 'bzrlib/tests/test_globbing.py'
--- bzrlib/tests/test_globbing.py	2010-06-30 13:49:02 +0000
+++ bzrlib/tests/test_globbing.py	2010-07-09 16:16:11 +0000
@@ -314,7 +314,7 @@
         patterns = [u'RE:[']
         g = Globster(patterns)
         e = self.assertRaises(errors.InvalidPattern, g.match, 'foo')
-        self.assertContainsRe(e.message, "File.*ignore.*contains errors")
+        self.assertContainsRe(e.msg, "File.*ignore.*contains errors")
 
 
 class TestExceptionGlobster(TestCase):

=== modified file 'bzrlib/tests/test_lazy_regex.py'
--- bzrlib/tests/test_lazy_regex.py	2010-06-30 13:49:02 +0000
+++ bzrlib/tests/test_lazy_regex.py	2010-07-09 16:16:11 +0000
@@ -70,8 +70,7 @@
         # As p.match is lazy, we make it into a lambda so its handled
         # by assertRaises correctly.
         e = self.assertRaises(errors.InvalidPattern, lambda: p.match('foo'))
-        self.assertEqual(e.message,
-            '"RE:[" unexpected end of regular expression')
+        self.assertEqual(e.msg, '"RE:[" unexpected end of regular expression')
 
 
 class TestLazyCompile(tests.TestCase):

